==> pas-0.2.0-beta%2B1.21.1-sources.jar: com/danrus/render/PlayerArmorStandModel.java <==
package com.danrus.render;

import com.danrus.utils.StringUtils;
import com.danrus.utils.interfaces.ModelWithCape;
import com.google.common.collect.ImmutableList;
import net.minecraft.class_1531;
import net.minecraft.class_2379;
import net.minecraft.class_2561;
import net.minecraft.class_548;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_630;
import net.minecraft.client.model.*;
import java.util.List;

//? if >=1.21.2 {
/*import net.minecraft.client.render.entity.state.ArmorStandEntityRenderState;
*///?}

public class PlayerArmorStandModel extends class_548 implements ModelWithCape {
//    private final List<ModelPart> parts;
    public final class_630 leftSleeve;
    public final class_630 rightSleeve;
    public final class_630 leftPants;
    public final class_630 rightPants;

    // SLIM
    public final class_630 leftSlimArm;
    public final class_630 rightSlimArm;
    public final class_630 leftSlimSleeve;
    public final class_630 rightSlimSleeve;

    // ORIGINAL
    public final class_630 rightBodyStick;
    public final class_630 leftBodyStick;
    public final class_630 shoulderStick;
    public final class_630 basePlate;

    public final class_630 originalHead;
    public final class_630 originalBody;
    public final class_630 originalRightArm;
    public final class_630 originalLeftArm;
    public final class_630 originalRightLeg;
    public final class_630 originalLeftLeg;

    public final class_630 jacket;
    private final class_630 cloak;

    public PlayerArmorStandModel(class_630 root) {
        super(root);
        this.cloak = root.method_32086("cloak");
        this.leftSleeve = root.method_32086("left_sleeve");
        this.rightSleeve = root.method_32086("right_sleeve");
        this.leftPants = root.method_32086("left_pants");
        this.rightPants = root.method_32086("right_pants");
        this.jacket = root.method_32086("jacket");

        // SLIM
        this.leftSlimArm = root.method_32086("left_slim_arm");
        this.rightSlimArm = root.method_32086("right_slim_arm");
        this.leftSlimSleeve = root.method_32086("left_slim_sleeve");
        this.rightSlimSleeve = root.method_32086("right_slim_sleeve");

        // ORIGINAL
        this.rightBodyStick = root.method_32086("right_body_stick");
        this.leftBodyStick = root.method_32086("left_body_stick");
        this.shoulderStick = root.method_32086("shoulder_stick");
        this.basePlate = root.method_32086("base_plate");

        this.originalHead = root.method_32086("original_head");
        this.originalBody = root.method_32086("original_body");
        this.originalRightArm = root.method_32086("original_right_arm");
        this.originalLeftArm = root.method_32086("original_left_arm");
        this.originalRightLeg = root.method_32086("original_right_leg");
        this.originalLeftLeg = root.method_32086("original_left_leg");

        this.field_3394.field_3665 = true;

        this.leftSleeve.field_3665 = true;
        this.rightSleeve.field_3665 = true;
        this.leftPants.field_3665 = true;
        this.rightPants.field_3665 = true;
        this.jacket.field_3665 = true;

        this.rightBodyStick.field_3665 = false;
        this.leftBodyStick.field_3665 = false;
        this.shoulderStick.field_3665 = false;
        this.basePlate.field_3665 = false;

//        this.parts = root.traverse().filter(part -> !part.isEmpty()).collect(ImmutableList.toImmutableList());
    }

    public static class_5607 method_32686(class_5605 dilation)  {
        class_5609 modelData = class_572.method_32011(dilation, 0.0F);
        class_5610 modelPartData = modelData.method_32111();
        modelPartData.method_32117("cloak", class_5606.method_32108().method_32101(0, 0).method_32099(-5.0F, 0.0F, -1.0F, 10.0F, 16.0F, 1.0F, dilation, 1.0F, 0.5F), pivot(0.0F, 0.0F, 0.0F));

        modelPartData.method_32117("left_arm", class_5606.method_32108().method_32101(32, 48).method_32098(-1.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_sleeve", class_5606.method_32108().method_32101(48, 48).method_32098(-1.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("right_sleeve", class_5606.method_32108().method_32101(40, 32).method_32098(-3.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_leg", class_5606.method_32108().method_32101(16, 48).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("left_pants", class_5606.method_32108().method_32101(0, 48).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("right_pants", class_5606.method_32108().method_32101(0, 32).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("jacket", class_5606.method_32108().method_32101(16, 32).method_32098(-4.0F, 0.0F, -2.0F, 8.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), class_5603.field_27701);

        modelPartData.method_32117("right_body_stick", class_5606.method_32108().method_32101(16, 0).method_32098(-0.5F, 0.0F, -0.5F, 1.0F, 7.0F, 1.0F, dilation), pivot(-4.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_body_stick", class_5606.method_32108().method_32101(48, 0).method_32098(-0.5F, 0.0F, -0.5F, 1.0F, 7.0F, 1.0F, dilation), pivot(4.0F, 2.0F, 0.0F));
        modelPartData.method_32117("shoulder_stick", class_5606.method_32108().method_32101(0, 0).method_32098(-6.5F, -0.5F, -0.5F, 13.0F, 1.0F, 1.0F, dilation), pivot(0.0F, 2.0F, 0.0F));
        modelPartData.method_32117("base_plate", class_5606.method_32108().method_32101(0, 32).method_32098(-6.0F, 0.0F, -6.0F, 12.0F, 1.0F, 12.0F, dilation), pivot(0.0F, 23.0F, 0.0F));

        // slim
        modelPartData.method_32117("left_slim_arm", class_5606.method_32108().method_32101(32, 48).method_32098(-1.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation), pivot(5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("right_slim_arm", class_5606.method_32108().method_32101(40, 16).method_32098(-2.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation), pivot(-5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("left_slim_sleeve", class_5606.method_32108().method_32101(48, 48).method_32098(-1.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("right_slim_sleeve", class_5606.method_32108().method_32101(40, 32).method_32098(-2.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-5.0F, 2.5F, 0.0F));

        // original
        modelPartData.method_32117("original_head", class_5606.method_32108().method_32101(0, 0).method_32097(-1.0F, -7.0F, -1.0F, 2.0F, 7.0F, 2.0F), pivot(0.0F, 1.0F, 0.0F));
        modelPartData.method_32117("original_body", class_5606.method_32108().method_32101(0, 26).method_32097(-6.0F, 0.0F, -1.5F, 12.0F, 3.0F, 3.0F), class_5603.field_27701);
        modelPartData.method_32117("original_right_arm", class_5606.method_32108().method_32101(24, 0).method_32097(-2.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F), pivot(-5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("original_left_arm", class_5606.method_32108().method_32101(32, 16).method_32096().method_32097(0.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("original_right_leg", class_5606.method_32108().method_32101(8, 0).method_32097(-1.0F, 0.0F, -1.0F, 2.0F, 11.0F, 2.0F), pivot(-1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("original_left_leg", class_5606.method_32108().method_32101(40, 16).method_32096().method_32097(-1.0F, 0.0F, -1.0F, 2.0F, 11.0F, 2.0F), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("right_body_stick", class_5606.method_32108().method_32101(16, 0).method_32097(-3.0F, 3.0F, -1.0F, 2.0F, 7.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("left_body_stick", class_5606.method_32108().method_32101(48, 16).method_32097(1.0F, 3.0F, -1.0F, 2.0F, 7.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("shoulder_stick", class_5606.method_32108().method_32101(0, 48).method_32097(-4.0F, 10.0F, -1.0F, 8.0F, 2.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("base_plate", class_5606.method_32108().method_32101(0, 32).method_32097(-6.0F, 11.0F, -6.0F, 12.0F, 1.0F, 12.0F), pivot(0.0F, 12.0F, 0.0F));

        return class_5607.method_32110(modelData, 64, 64);
    }

    public class_630 getCape(){
        return this.cloak;
    }

    private static class_5603 pivot(float x, float y, float z) {
        //? <=1.21.4 {
        return class_5603.method_32090(x, y, z);
         //?} else {
        /*return ModelTransform.origin(x, y, z);
        *///?}

    }

    private static float getPitch(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10256();
         //?} else {
        /*return angle.pitch();
        *///?}
    }

    private static float getYaw(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10257();
         //?} else {
        /*return angle.yaw();
        *///?}
    }

    private static float getRoll(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10258();
         //?} else {
        /*return angle.roll();
        *///?}
    }

    //? if <1.21.2
    @Override
    public Iterable<class_630> method_22946() {
        return ImmutableList.of(this.field_3398, this.field_3394, this.originalHead);
    }

    //? if <1.21.2
    @Override
    public Iterable<class_630> method_22948() {
        return ImmutableList.of(
                this.field_3391,
                this.field_3401,
                this.field_27433,
                this.field_3392,
                this.field_3397,
                this.jacket,
                this.rightSleeve,
                this.leftSleeve,
                this.rightPants,
                this.leftPants,
                this.leftSlimSleeve,
                this.rightSlimSleeve,
                this.leftSlimArm,
                this.rightSlimArm,
                this.originalBody,
                this.originalRightArm,
                this.originalLeftArm,
                this.originalRightLeg,
                this.originalLeftLeg,
                this.basePlate,
                this.leftBodyStick,
                this.rightBodyStick,
                this.shoulderStick
        );
    }

    //? if <1.21.2 {
    public void method_17066(class_1531 armorStand, float f, float g, float h, float i, float j){
        super.method_17066(armorStand, f, g, h, i, j);
        boolean showBase = armorStand.method_6901();
        boolean showArms = armorStand.method_6929();
        class_2561 customName = armorStand.method_5797();
        class_2379 bodyRotation = armorStand.method_6923();

    //?} else {
    /*@Override
    public void setAngles(ArmorStandEntityRenderState armorStand) {
        super.setAngles(armorStand);
        boolean showBase = armorStand.showBasePlate;
        boolean showArms = armorStand.showArms;
        Text customName = armorStand.customName;
        EulerAngle bodyRotation = armorStand.bodyRotation;
    *///?}
        this.leftPants.method_17138(field_3397);
        this.rightPants.method_17138(field_3392);

        this.leftSleeve.method_17138(field_27433);
        this.rightSleeve.method_17138(field_3401);

        this.leftSlimArm.method_17138(field_27433);
        this.rightSlimArm.method_17138(field_3401);
        this.leftSlimSleeve.method_17138(field_27433);
        this.rightSlimSleeve.method_17138(field_3401);

        this.originalBody.method_17138(field_3391);
        this.originalHead.method_17138(field_3398);
        this.originalRightArm.method_17138(field_3401);
        this.originalLeftArm.method_17138(field_27433);
        this.originalRightLeg.method_17138(field_3392);
        this.originalLeftLeg.method_17138(field_3397);

        this.jacket.method_17138(field_3391);

        //? <=1.21.1 {
        this.basePlate.field_3675 = ((float)Math.PI / 180F) * -armorStand.method_36454();
         //?} else {
        /*this.basePlate.yaw = ((float)Math.PI / 180F) * -armorStand.yaw;
        *///?}



        if (customName == null) {
            this.setModelVisibility(false, false);
            this.originalLeftArm.field_3665 = showArms;
            this.originalRightArm.field_3665 = showArms;
            this.basePlate.field_3665 = showBase;
            this.rightBodyStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.rightBodyStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.rightBodyStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            this.leftBodyStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.leftBodyStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.leftBodyStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            this.shoulderStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.shoulderStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.shoulderStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            return;
        }
        if (customName != null){
            if (StringUtils.matchASName(customName.getString()).get(1).contains("S")){
                this.setModelVisibility(true, true);
            } else {
                this.setModelVisibility(true, false);
            }
        }


    }
    
    private void setModelVisibility(boolean player, boolean slim) {
        this.field_3394.field_3665 = player;
        this.field_3398.field_3665 = player;
        this.field_3391.field_3665 = player;
        this.jacket.field_3665 = player;
        this.field_27433.field_3665 = player && !slim;
        this.field_3401.field_3665 = player && !slim;
        this.leftSleeve.field_3665 = player && !slim;
        this.rightSleeve.field_3665 = player && !slim;
        this.leftPants.field_3665 = player;
        this.rightPants.field_3665 = player;
        this.field_3397.field_3665 = player;
        this.field_3392.field_3665 = player;

        this.leftSlimArm.field_3665 = player && slim;
        this.rightSlimArm.field_3665 = player && slim;
        this.leftSlimSleeve.field_3665 = player && slim;
        this.rightSlimSleeve.field_3665 = player && slim;

        this.originalHead.field_3665 = !player;
        this.originalBody.field_3665 = !player;
        this.originalRightArm.field_3665 = !player;
        this.originalLeftArm.field_3665 = !player;
        this.originalRightLeg.field_3665 = !player;
        this.originalLeftLeg.field_3665 = !player;

        this.rightBodyStick.field_3665 = !player;
        this.leftBodyStick.field_3665 = !player;
        this.shoulderStick.field_3665 = !player;
        this.basePlate.field_3665 = !player;

        this.cloak.field_3665 = false;
    }

}

==> pas-0.2.1-beta%2B1.21.2-sources.jar: com/danrus/render/PlayerArmorStandModel.java <==
package com.danrus.render;

import com.danrus.utils.StringUtils;
import com.danrus.utils.interfaces.ModelWithCape;
import com.google.common.collect.ImmutableList;
import net.minecraft.class_2379;
import net.minecraft.class_2561;
import net.minecraft.class_548;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_630;
import net.minecraft.class_9998;
import net.minecraft.client.model.*;
import java.util.List;

public class PlayerArmorStandModel extends class_548 implements ModelWithCape {
//    private final List<ModelPart> parts;
    public final class_630 leftSleeve;
    public final class_630 rightSleeve;
    public final class_630 leftPants;
    public final class_630 rightPants;

    // SLIM
    public final class_630 leftSlimArm;
    public final class_630 rightSlimArm;
    public final class_630 leftSlimSleeve;
    public final class_630 rightSlimSleeve;

    // ORIGINAL
    public final class_630 rightBodyStick;
    public final class_630 leftBodyStick;
    public final class_630 shoulderStick;
    public final class_630 basePlate;

    public final class_630 originalHead;
    public final class_630 originalBody;
    public final class_630 originalRightArm;
    public final class_630 originalLeftArm;
    public final class_630 originalRightLeg;
    public final class_630 originalLeftLeg;

    public final class_630 jacket;
    private final class_630 cloak;

    public PlayerArmorStandModel(class_630 root) {
        super(root);
        this.cloak = root.method_32086("cloak");
        this.leftSleeve = root.method_32086("left_sleeve");
        this.rightSleeve = root.method_32086("right_sleeve");
        this.leftPants = root.method_32086("left_pants");
        this.rightPants = root.method_32086("right_pants");
        this.jacket = root.method_32086("jacket");

        // SLIM
        this.leftSlimArm = root.method_32086("left_slim_arm");
        this.rightSlimArm = root.method_32086("right_slim_arm");
        this.leftSlimSleeve = root.method_32086("left_slim_sleeve");
        this.rightSlimSleeve = root.method_32086("right_slim_sleeve");

        // ORIGINAL
        this.rightBodyStick = root.method_32086("right_body_stick");
        this.leftBodyStick = root.method_32086("left_body_stick");
        this.shoulderStick = root.method_32086("shoulder_stick");
        this.basePlate = root.method_32086("base_plate");

        this.originalHead = root.method_32086("original_head");
        this.originalBody = root.method_32086("original_body");
        this.originalRightArm = root.method_32086("original_right_arm");
        this.originalLeftArm = root.method_32086("original_left_arm");
        this.originalRightLeg = root.method_32086("original_right_leg");
        this.originalLeftLeg = root.method_32086("original_left_leg");

        this.field_3394.field_3665 = true;

        this.leftSleeve.field_3665 = true;
        this.rightSleeve.field_3665 = true;
        this.leftPants.field_3665 = true;
        this.rightPants.field_3665 = true;
        this.jacket.field_3665 = true;

        this.rightBodyStick.field_3665 = false;
        this.leftBodyStick.field_3665 = false;
        this.shoulderStick.field_3665 = false;
        this.basePlate.field_3665 = false;

//        this.parts = root.traverse().filter(part -> !part.isEmpty()).collect(ImmutableList.toImmutableList());
    }

    public static class_5607 method_32686(class_5605 dilation)  {
        class_5609 modelData = class_572.method_32011(dilation, 0.0F);
        class_5610 modelPartData = modelData.method_32111();
        modelPartData.method_32117("cloak", class_5606.method_32108().method_32101(0, 0).method_32099(-5.0F, 0.0F, -1.0F, 10.0F, 16.0F, 1.0F, dilation, 1.0F, 0.5F), pivot(0.0F, 0.0F, 0.0F));

        modelPartData.method_32117("left_arm", class_5606.method_32108().method_32101(32, 48).method_32098(-1.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_sleeve", class_5606.method_32108().method_32101(48, 48).method_32098(-1.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("right_sleeve", class_5606.method_32108().method_32101(40, 32).method_32098(-3.0F, -2.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_leg", class_5606.method_32108().method_32101(16, 48).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("left_pants", class_5606.method_32108().method_32101(0, 48).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("right_pants", class_5606.method_32108().method_32101(0, 32).method_32098(-2.0F, 0.0F, -2.0F, 4.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("jacket", class_5606.method_32108().method_32101(16, 32).method_32098(-4.0F, 0.0F, -2.0F, 8.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), class_5603.field_27701);

        modelPartData.method_32117("right_body_stick", class_5606.method_32108().method_32101(16, 0).method_32098(-0.5F, 0.0F, -0.5F, 1.0F, 7.0F, 1.0F, dilation), pivot(-4.0F, 2.0F, 0.0F));
        modelPartData.method_32117("left_body_stick", class_5606.method_32108().method_32101(48, 0).method_32098(-0.5F, 0.0F, -0.5F, 1.0F, 7.0F, 1.0F, dilation), pivot(4.0F, 2.0F, 0.0F));
        modelPartData.method_32117("shoulder_stick", class_5606.method_32108().method_32101(0, 0).method_32098(-6.5F, -0.5F, -0.5F, 13.0F, 1.0F, 1.0F, dilation), pivot(0.0F, 2.0F, 0.0F));
        modelPartData.method_32117("base_plate", class_5606.method_32108().method_32101(0, 32).method_32098(-6.0F, 0.0F, -6.0F, 12.0F, 1.0F, 12.0F, dilation), pivot(0.0F, 23.0F, 0.0F));

        // slim
        modelPartData.method_32117("left_slim_arm", class_5606.method_32108().method_32101(32, 48).method_32098(-1.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation), pivot(5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("right_slim_arm", class_5606.method_32108().method_32101(40, 16).method_32098(-2.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation), pivot(-5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("left_slim_sleeve", class_5606.method_32108().method_32101(48, 48).method_32098(-1.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(5.0F, 2.5F, 0.0F));
        modelPartData.method_32117("right_slim_sleeve", class_5606.method_32108().method_32101(40, 32).method_32098(-2.0F, -2.0F, -2.0F, 3.0F, 12.0F, 4.0F, dilation.method_32094(0.25F)), pivot(-5.0F, 2.5F, 0.0F));

        // original
        modelPartData.method_32117("original_head", class_5606.method_32108().method_32101(0, 0).method_32097(-1.0F, -7.0F, -1.0F, 2.0F, 7.0F, 2.0F), pivot(0.0F, 1.0F, 0.0F));
        modelPartData.method_32117("original_body", class_5606.method_32108().method_32101(0, 26).method_32097(-6.0F, 0.0F, -1.5F, 12.0F, 3.0F, 3.0F), class_5603.field_27701);
        modelPartData.method_32117("original_right_arm", class_5606.method_32108().method_32101(24, 0).method_32097(-2.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F), pivot(-5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("original_left_arm", class_5606.method_32108().method_32101(32, 16).method_32096().method_32097(0.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F), pivot(5.0F, 2.0F, 0.0F));
        modelPartData.method_32117("original_right_leg", class_5606.method_32108().method_32101(8, 0).method_32097(-1.0F, 0.0F, -1.0F, 2.0F, 11.0F, 2.0F), pivot(-1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("original_left_leg", class_5606.method_32108().method_32101(40, 16).method_32096().method_32097(-1.0F, 0.0F, -1.0F, 2.0F, 11.0F, 2.0F), pivot(1.9F, 12.0F, 0.0F));
        modelPartData.method_32117("right_body_stick", class_5606.method_32108().method_32101(16, 0).method_32097(-3.0F, 3.0F, -1.0F, 2.0F, 7.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("left_body_stick", class_5606.method_32108().method_32101(48, 16).method_32097(1.0F, 3.0F, -1.0F, 2.0F, 7.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("shoulder_stick", class_5606.method_32108().method_32101(0, 48).method_32097(-4.0F, 10.0F, -1.0F, 8.0F, 2.0F, 2.0F), class_5603.field_27701);
        modelPartData.method_32117("base_plate", class_5606.method_32108().method_32101(0, 32).method_32097(-6.0F, 11.0F, -6.0F, 12.0F, 1.0F, 12.0F), pivot(0.0F, 12.0F, 0.0F));

        return class_5607.method_32110(modelData, 64, 64);
    }

    public class_630 getCape(){
        return this.cloak;
    }

    private static class_5603 pivot(float x, float y, float z) {
        //? <=1.21.4 {
        return class_5603.method_32090(x, y, z);
         //?} else {
        /*return ModelTransform.origin(x, y, z);
        *///?}

    }

    private static float getPitch(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10256();
         //?} else {
        /*return angle.pitch();
        *///?}
    }

    private static float getYaw(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10257();
         //?} else {
        /*return angle.yaw();
        *///?}
    }

    private static float getRoll(class_2379 angle){
        //? <=1.21.4 {
        return angle.method_10258();
         //?} else {
        /*return angle.roll();
        *///?}
    }

    //? if <1.21.2
    /*@Override*/
    public Iterable<class_630> getHeadParts() {
        return ImmutableList.of(this.field_3398, this.field_3394, this.originalHead);
    }

    //? if <1.21.2
    /*@Override*/
    public Iterable<class_630> getBodyParts() {
        return ImmutableList.of(
                this.field_3391,
                this.field_3401,
                this.field_27433,
                this.field_3392,
                this.field_3397,
                this.jacket,
                this.rightSleeve,
                this.leftSleeve,
                this.rightPants,
                this.leftPants,
                this.leftSlimSleeve,
                this.rightSlimSleeve,
                this.leftSlimArm,
                this.rightSlimArm,
                this.originalBody,
                this.originalRightArm,
                this.originalLeftArm,
                this.originalRightLeg,
                this.originalLeftLeg,
                this.basePlate,
                this.leftBodyStick,
                this.rightBodyStick,
                this.shoulderStick
        );
    }

    //? if <1.21.2 {
    /*public void setAngles(ArmorStandEntity armorStand, float f, float g, float h, float i, float j){
        super.setAngles(armorStand, f, g, h, i, j);
        boolean showBase = armorStand.shouldHideBasePlate();
        boolean showArms = armorStand.shouldShowArms();
        Text customName = armorStand.getCustomName();
        EulerAngle bodyRotation = armorStand.getBodyRotation();

    *///?} else {
    @Override
    public void method_17066(class_9998 armorStand) {
        super.method_17066(armorStand);
        boolean showBase = armorStand.field_53250;
        boolean showArms = armorStand.field_53249;
        class_2561 customName = armorStand.field_53464;
        class_2379 bodyRotation = armorStand.field_53252;
    //?}
        this.leftPants.method_17138(field_3397);
        this.rightPants.method_17138(field_3392);

        this.leftSleeve.method_17138(field_27433);
        this.rightSleeve.method_17138(field_3401);

        this.leftSlimArm.method_17138(field_27433);
        this.rightSlimArm.method_17138(field_3401);
        this.leftSlimSleeve.method_17138(field_27433);
        this.rightSlimSleeve.method_17138(field_3401);

        this.originalBody.method_17138(field_3391);
        this.originalHead.method_17138(field_3398);
        this.originalRightArm.method_17138(field_3401);
        this.originalLeftArm.method_17138(field_27433);
        this.originalRightLeg.method_17138(field_3392);
        this.originalLeftLeg.method_17138(field_3397);

        this.jacket.method_17138(field_3391);

        //? <=1.21.1 {
        /*this.basePlate.yaw = ((float)Math.PI / 180F) * -armorStand.getYaw();
         *///?} else {
        this.basePlate.field_3675 = ((float)Math.PI / 180F) * -armorStand.field_53245;
        //?}



        if (customName == null) {
            this.setModelVisibility(false, false);
            this.originalLeftArm.field_3665 = showArms;
            this.originalRightArm.field_3665 = showArms;
            this.basePlate.field_3665 = showBase;
            this.rightBodyStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.rightBodyStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.rightBodyStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            this.leftBodyStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.leftBodyStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.leftBodyStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            this.shoulderStick.field_3654 = ((float)Math.PI / 180F) * getPitch(bodyRotation);
            this.shoulderStick.field_3675 = ((float)Math.PI / 180F) * getYaw(bodyRotation);
            this.shoulderStick.field_3674 = ((float)Math.PI / 180F) * getRoll(bodyRotation);
            return;
        }
        if (customName != null){
            if (StringUtils.matchASName(customName.getString()).get(1).contains("S")){
                this.setModelVisibility(true, true);
            } else {
                this.setModelVisibility(true, false);
            }
        }


    }
    
    private void setModelVisibility(boolean player, boolean slim) {
        this.field_3394.field_3665 = player;
        this.field_3398.field_3665 = player;
        this.field_3391.field_3665 = player;
        this.jacket.field_3665 = player;
        this.field_27433.field_3665 = player && !slim;
        this.field_3401.field_3665 = player && !slim;
        this.leftSleeve.field_3665 = player && !slim;
        this.rightSleeve.field_3665 = player && !slim;
        this.leftPants.field_3665 = player;
        this.rightPants.field_3665 = player;
        this.field_3397.field_3665 = player;
        this.field_3392.field_3665 = player;

        this.leftSlimArm.field_3665 = player && slim;
        this.rightSlimArm.field_3665 = player && slim;
        this.leftSlimSleeve.field_3665 = player && slim;
        this.rightSlimSleeve.field_3665 = player && slim;

        this.originalHead.field_3665 = !player;
        this.originalBody.field_3665 = !player;
        this.originalRightArm.field_3665 = !player;
        this.originalLeftArm.field_3665 = !player;
        this.originalRightLeg.field_3665 = !player;
        this.originalLeftLeg.field_3665 = !player;

        this.rightBodyStick.field_3665 = !player;
        this.leftBodyStick.field_3665 = !player;
        this.shoulderStick.field_3665 = !player;
        this.basePlate.field_3665 = !player;

        this.cloak.field_3665 = false;
    }

}
